.. django-alexa documentation documentation master file, created by
   sphinx-quickstart on Mon Jan 14 22:23:21 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-alexa documentation's documentation!
======================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about-django-alexa



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
